/* This is a SADARC Arduino class project.
 *  Driving the 4x7seg LED display as well as the 8 way high side driver.
 * 
 */
#define VERSION "SADARC_8_Hi_Side_Drive7"

#include "PCF8574.h"
PCF8574 PCF_01(0x3E);                 // set PCH8574 address here.
#include "SevSeg.h"
SevSeg sevseg; //Instantiate a seven segment controller object

void setup()
{ PCF_01.begin();
  byte numDigits = 4;
  // pins in order to suit the TSB5882 display
  // digits 1, 2, 3, 4 (staring from the left)
  byte digitPins[] = {11, 10, 8, 4};
  // segment  a, b, c, d, e, f, g, dp
  byte segmentPins[] = {13, 7, 9, 12, 5, 6, 2, 3};

  bool resistorsOnSegments = true; // 'false' means resistors are on digit pins
  /*
      byte hardwareConfig = COMMON_CATHODE;     // = 0 (digitOnVal=LOW,  segmentOnVal = HIGH)
      byte hardwareConfig = COMMON_ANODE;       // = 1 (digitOnVal=HIGH, segmentOnVal = LOW)
      byte hardwareConfig = N_TRANSISTORS;      // = 2 (digitOnVal=HIGH, segmentOnVal = HIGH)
      byte hardwareConfig = P_TRANSISTORS;      // = 3 (digitOnVal=LOW,  segmentOnVal = LOW)
      byte hardwareConfig = NP_COMMON_ANODE;    // = 0 (digitOnVal=LOW,  segmentOnVal = HIGH)
      byte hardwareConfig = NP_COMMON_CATHODE;  // = 1 (digitOnVal=HIGH, segmentOnVal = LOW)
  */
  byte hardwareConfig = P_TRANSISTORS; // PNP transistors on common Anodes. Arduino ports on Cathodes.

  bool updateWithDelays = false; // Default 'false' is Recommended
  bool leadingZeros = false; // Use 'true' if you'd like to keep the leading zeros
  bool disableDecPoint = false; // Use 'true' if your decimal point doesn't exist or isn't connected

  sevseg.begin(hardwareConfig, numDigits, digitPins, segmentPins, resistorsOnSegments,
               updateWithDelays, leadingZeros, disableDecPoint);
  sevseg.setBrightness(100);
}

void loop()
{
  static unsigned long timer = millis();
  static int deciSeconds = 0;

  if (millis() - timer >= 100) {
    timer += 100;
    deciSeconds++; // 100 milliSeconds is equal to 1 deciSecond

    if (deciSeconds == 10000) { // Reset to 0 after counting for 1000 seconds.
      deciSeconds = 0;
    }
    sevseg.setNumber(deciSeconds, 1);
     PCF_01.write8(deciSeconds); 
    
  }

  sevseg.refreshDisplay(); // Must run repeatedly
 
}
